pub struct PartialFile {
pub id: Option<String>,
pub hash: Option<String>,
pub machine_id: Option<String>,
pub asset_path: Option<String>,
pub local_path: Option<String>,
pub version: Option<u32>,
}Fields
id: Option<String>hash: Option<String>machine_id: Option<String>asset_path: Option<String>local_path: Option<String>version: Option<u32>Trait Implementations
Sourceimpl Clone for PartialFile
impl Clone for PartialFile
Sourcefn clone(&self) -> PartialFile
fn clone(&self) -> PartialFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PartialFile
impl Default for PartialFile
Sourcefn default() -> PartialFile
fn default() -> PartialFile
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartialFile
impl<'de> Deserialize<'de> for PartialFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Partial for PartialFile
impl Partial for PartialFile
Sourcetype Item = PartialFile
type Item = PartialFile
The type of the partial structure, that may have
Some values.Sourcefn apply_some(&mut self, partial: Self::Item) -> bool
fn apply_some(&mut self, partial: Self::Item) -> bool
Applies
Some values from Partial::Item to self, returning true when
updates were made, and false when nothing was applied. Read moreAuto Trait Implementations
impl Freeze for PartialFile
impl RefUnwindSafe for PartialFile
impl Send for PartialFile
impl Sync for PartialFile
impl Unpin for PartialFile
impl UnsafeUnpin for PartialFile
impl UnwindSafe for PartialFile