pub struct Instance {
pub id: String,
pub hash: String,
pub name: String,
pub service_id: String,
pub service_type_code: String,
pub color: String,
pub machine_id: String,
pub status: InstanceStatus,
pub message: Option<String>,
pub cluster_id: Option<String>,
}Fields
id: Stringhash: Stringname: Stringservice_id: Stringservice_type_code: Stringcolor: Stringmachine_id: Stringstatus: InstanceStatusmessage: Option<String>cluster_id: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Instance
impl<'de> Deserialize<'de> for Instance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Partial for Instance
impl Partial for Instance
Sourcetype Item = PartialInstance
type Item = PartialInstance
The type of the partial structure, that may have
Some values.Sourcefn apply_some(&mut self, partial: Self::Item) -> bool
fn apply_some(&mut self, partial: Self::Item) -> bool
Applies
Some values from Partial::Item to self, returning true when
updates were made, and false when nothing was applied. Read moreimpl StructuralPartialEq for Instance