pub struct PartialInstance {
pub id: Option<String>,
pub hash: Option<String>,
pub name: Option<String>,
pub service_id: Option<String>,
pub service_type_code: Option<String>,
pub color: Option<String>,
pub machine_id: Option<String>,
pub status: Option<InstanceStatus>,
pub message: Option<Option<String>>,
pub cluster_id: Option<Option<String>>,
}Fields
id: Option<String>hash: Option<String>name: Option<String>service_id: Option<String>service_type_code: Option<String>color: Option<String>machine_id: Option<String>status: Option<InstanceStatus>message: Option<Option<String>>cluster_id: Option<Option<String>>Trait Implementations
Sourceimpl Clone for PartialInstance
impl Clone for PartialInstance
Sourcefn clone(&self) -> PartialInstance
fn clone(&self) -> PartialInstance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PartialInstance
impl Default for PartialInstance
Sourcefn default() -> PartialInstance
fn default() -> PartialInstance
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartialInstance
impl<'de> Deserialize<'de> for PartialInstance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Partial for PartialInstance
impl Partial for PartialInstance
Sourcetype Item = PartialInstance
type Item = PartialInstance
The type of the partial structure, that may have
Some values.Sourcefn apply_some(&mut self, partial: Self::Item) -> bool
fn apply_some(&mut self, partial: Self::Item) -> bool
Applies
Some values from Partial::Item to self, returning true when
updates were made, and false when nothing was applied. Read moreAuto Trait Implementations
impl Freeze for PartialInstance
impl RefUnwindSafe for PartialInstance
impl Send for PartialInstance
impl Sync for PartialInstance
impl Unpin for PartialInstance
impl UnsafeUnpin for PartialInstance
impl UnwindSafe for PartialInstance