pub struct Machine {
pub id: String,
pub hash: String,
pub name: Option<String>,
pub dns_name: Option<String>,
pub exec_name: Option<String>,
pub addresses: Vec<String>,
}Fields
id: Stringhash: Stringname: Option<String>dns_name: Option<String>exec_name: Option<String>addresses: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Machine
impl<'de> Deserialize<'de> for Machine
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Partial for Machine
impl Partial for Machine
Sourcetype Item = PartialMachine
type Item = PartialMachine
The type of the partial structure, that may have
Some values.Sourcefn apply_some(&mut self, partial: Self::Item) -> bool
fn apply_some(&mut self, partial: Self::Item) -> bool
Applies
Some values from Partial::Item to self, returning true when
updates were made, and false when nothing was applied. Read moreimpl StructuralPartialEq for Machine