pub struct PartialMachine {
pub id: Option<String>,
pub hash: Option<String>,
pub name: Option<Option<String>>,
pub dns_name: Option<Option<String>>,
pub exec_name: Option<Option<String>>,
pub addresses: Option<Vec<String>>,
}Fields
id: Option<String>hash: Option<String>name: Option<Option<String>>dns_name: Option<Option<String>>exec_name: Option<Option<String>>addresses: Option<Vec<String>>Trait Implementations
Sourceimpl Clone for PartialMachine
impl Clone for PartialMachine
Sourcefn clone(&self) -> PartialMachine
fn clone(&self) -> PartialMachine
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PartialMachine
impl Default for PartialMachine
Sourcefn default() -> PartialMachine
fn default() -> PartialMachine
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartialMachine
impl<'de> Deserialize<'de> for PartialMachine
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Partial for PartialMachine
impl Partial for PartialMachine
Sourcetype Item = PartialMachine
type Item = PartialMachine
The type of the partial structure, that may have
Some values.Sourcefn apply_some(&mut self, partial: Self::Item) -> bool
fn apply_some(&mut self, partial: Self::Item) -> bool
Applies
Some values from Partial::Item to self, returning true when
updates were made, and false when nothing was applied. Read moreAuto Trait Implementations
impl Freeze for PartialMachine
impl RefUnwindSafe for PartialMachine
impl Send for PartialMachine
impl Sync for PartialMachine
impl Unpin for PartialMachine
impl UnsafeUnpin for PartialMachine
impl UnwindSafe for PartialMachine